@@ -2,10 +2,10 @@
 
 Context : SRP
 Module  : Polarimetry
-Version : 1.2.0
+Version : 1.3.0
 Author  : Stefano Covino
-Date    : 18/11/2015
-E-mail  : stefano.covino@brera.inaf.it
+Date    : 17/01/2023
+E-mail  : stefano.covino@inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
 Usage   : to be imported
@@ -14,11 +14,12 @@ History : (15/02/2012) First named version.
         : (10/11/2015) resid, centerGauss and getBackground added.
         : (13/11/2015) MinMax added.
         : (18/11/2015) centerMoment added.
+        : (17/01/2023) AirmAss functions added.
 """
 
 
-__all__ = ['centerGauss', 'centerMoment', 'Counts2Mag', 'Mag2Counts', 'getBackground',
-            'MinMax', 'resid']
+__all__ = ['AirMass', 'centerGauss', 'centerMoment', 'Counts2Mag',
+            'Mag2Counts', 'getBackground', 'MinMax', 'resid']
 
 
 
